# This code is part of the 'enjuewemela' game
# License: GPLv3
# Main author: Facundo Batista
# Code, bug tracker, etc:
#   https://launchpad.net/enjuewemela/
#
"""Tests for sound management."""

from __future__ import division

import sys
import os

BASEDIR = os.path.dirname(os.path.realpath(__file__))
sys.path.insert(0, os.path.join(BASEDIR, "cocos"))

import config
config.BASEDIR = BASEDIR

import random

from cocos.director import director
director.init(width=800, height=600, audio_backend='sdl')

import cocos
import pyglet

pyglet.resource.path.append("jewels")
pyglet.resource.path.append("images")
pyglet.resource.reindex()

from gems import gems

# audio
from sound import sounds

class MainLayer(cocos.layer.Layer):
    """Main layer for the test."""

    _sounds = {
        'short': 'pumba',
        'long': 'magicdisap',
    }

    def __init__(self):
        super(MainLayer, self).__init__()

    def test(self, coord_x, coord_y, which_sound):
        """Play a sound and draw a mark."""
        # pumba!
        sndname = self._sounds[which_sound]
        sounds.play(sndname)

        # draw it!
        gem = gems[random.randint(0, 6)]
        gem.position = coord_x, coord_y
        self.add(gem)


class MouseManager(cocos.layer.Layer):
    """Manager for mouse events."""

    is_event_handler = True

    def __init__(self, main_layer):
        super(MouseManager, self).__init__()
        self.main_layer = main_layer

    def on_mouse_press(self, coord_x, coord_y, button, modifiers):
        """Called when mouse button is pressed."""
        if button == 1:    # left
            which = 'short'
        elif button == 4:  # right
            which = 'long'
        else:
            return

        x, y = director.get_virtual_coordinates(coord_x, coord_y)
        self.main_layer.test(x, y, which)


if __name__ == "__main__":
    m = MainLayer()
    main_scene = cocos.scene.Scene(m)
    main_scene.add(MouseManager(m), z=2)
    director.run(main_scene)
