# -*- coding: utf-8 -*-

# This code is part of the 'enjuewemela' game
# License: GPLv3
# Main author: Facundo Batista
# Code, bug tracker, etc:
#   https://launchpad.net/enjuewemela/
#
"""High scores window."""

import os
import pickle

from xdg.BaseDirectory import xdg_data_home

from cocos import layer
from cocos.director import director

import utils

WHITE = (255, 255, 255, 255)


class HighScores(layer.Layer):
    """Show the high scores."""

    _styles = [
        ('classic', 'Classic', (255, 0, 0, 255)),
        ('rush',    'Rush!',    (0, 0, 255, 255)),
        ('crazy',   'Crazy',   (0, 255, 0, 255)),
    ]

    def __init__(self):
        super(HighScores, self).__init__()

        f_varbl = utils.FontWriter(self, "Sansation")
        f_fixed = utils.FontWriter(self, "SV Basic Manual")

        fname = os.path.join(xdg_data_home, 'enjuewemela.hs')
        if not os.path.exists(fname):
            return

        try:
            with open(fname, 'rb') as fh:
                all_hs = pickle.load(fh)
        except Exception, e:
            print "WARNING: problems with the high score filename:", e
            return

        # some info for the initial drawing
        win_w, win_h = director.get_window_size()
        border = 50
        separ = 30

        # panels
        cant_paneles = len(self._styles)
        cant_separ = cant_paneles - 1
        panel_width = (win_w - border * 2 - separ * cant_separ) // cant_paneles
        alto_panel = win_h - border * 2

        x = border
        for i in range(cant_paneles):
            # x, y, w, h
            b = utils.Base(100, x, border, panel_width, alto_panel)
            self.add(b)
            x += panel_width + separ

        for i, (style, title, color) in enumerate(self._styles):
            # location of panel border
            panel_left = border + (panel_width + separ) * i
            panel_center = panel_left + panel_width // 2
            panel_right = panel_left + panel_width

            # title
            y = win_h - border - 40
            f_varbl(_(title), (panel_center, y), 30, "center", color=color)
            y -= 60

            for name, score in all_hs[style][:10]:
                f_varbl(name, (panel_left + 10, y), 16, "left", color=WHITE)
                s = "%10s" % score
                f_fixed(s, (panel_right - 10, y), 16, "right", color=WHITE)
                y -= 40
