
from __future__ import division

import math

from collections import namedtuple

"""Calculates the information for each level.

- fpp: frukis per point (how many frukis buys you each point of score)
- fps: frukis per second (only for timed games)
- lmp: level multiplier (to apply to the score)

When playing, you get some score, that score buys you frikus according to
the fpp parameter, and when you get over 'FRUKIS' quantity of frukis, you
pass to the next level.

When the game is timed, each
"""

# quantity of frukis to pass level
FRUKIS_LEVEL_LIMIT = 6000

# how many frukis user have at level start
INITIAL_FRUKIS = {
    'classic': 0,
    'rush': FRUKIS_LEVEL_LIMIT // 2,
    'crazy': FRUKIS_LEVEL_LIMIT // 2,
}

_Level = namedtuple("Level", "fpp fps lmp")

POINTS_PER_STYLE = {
    'classic': 1,
    'rush': 2,
    'crazy': 3,
}


def fpp(x):
    """Frukis per point."""
    return 10 * (math.e ** (-.5 * x))


def fps(x):
    """Frukis per second."""
    return 10 + 5 * x ** 2


def lmp(x):
    """Level multiplier."""
    return 1 + .7 * x ** 2


def get_level_factors(num):
    """Return the info for level num."""
    return _Level(fpp(num), fps(num), lmp(num))

if __name__ == "__main__":
    for i in range(10):
        l = get_level_factors(i)
        t = "Level %2d:    fpp:%7.3f  fps:%7.3f  lmp:%7.3f"
        print t % (i, l.fpp, l.fps, l.lmp)
