# This code is part of the 'enjuewemela' game
# License: GPLv3
# Main author: Facundo Batista
# Code, bug tracker, etc:
#   https://launchpad.net/enjuewemela/
#

"""Module to load and manage all the sounds."""

import glob
import os
import random

import pyglet

from cocos.audio.pygame import mixer, music

import config

# list of voices and effects, with each volume
EFFECTS = [
    ("pumba", .2),
    ("tic", .2),
    ("explosion", .9),
    ("magicdisap", .9),
]

VOICES = [
    ("game_over", 1),
    ("not_yet", 1),
    ("new_level", 1),
]


class Sounds(object):
    """Manager class for the sounds."""

    def __init__(self, locale="en"):
        self._sounds = {}

        effects_dir = os.path.join(config.BASEDIR, 'audio', 'effects')
        voices_dir  = os.path.join(config.BASEDIR, 'audio', 'voices', locale)

        for snddata, basedir in [(EFFECTS, effects_dir), (VOICES, voices_dir)]:
            for sndname, vol in snddata:
                if sndname in self._sounds:
                    raise ValueError("Repeated resource in sound.py")
                sound = mixer.Sound(os.path.join(basedir, sndname + '.ogg'))
                self._sounds[sndname] = (vol, sound)

        self.volume = 1

    def play(self, snd):
        """Play a sound."""
        if not self.volume:
            return

        (volume, sound) = self._sounds[snd]
        sound.set_volume(volume * self.volume)
        sound.play()


class Music(object):
    """Manager class for the music."""

    def __init__(self):
        # index music path and get the filenames
        fnames_wcard = os.path.join(config.BASEDIR, 'audio', 'music', '*.ogg')
        self.music_fnames = glob.glob(fnames_wcard)
        self._playing = True
        self._volume = .2
        self._random_play()
        pyglet.clock.schedule_interval(self._check_activity, 1)

    def _check_activity(self, _):
        """Check if music finished and start other one."""
        if not music.get_busy():
            self._random_play()

    def _random_play(self):
        """Plays a song randomly chosen."""
        to_play = random.choice(self.music_fnames)
        print "Random music", to_play
        music.load(to_play)
        music.play()
        music.set_volume(self._volume)

    def _set_volume(self, value):
        """Set the music volume."""
        self._volume = value
        music.set_volume(value)
        if value == 0:
            music.pause()
        else:
            music.unpause()

    def _get_volume(self):
        """Get the music volume."""
        return self._volume

    volume = property(_get_volume, _set_volume)


sounds = Sounds()
music_player = Music()
