# This code is part of the 'enjuewemela' game
# License: GPLv3
# Main author: Facundo Batista
# Code, bug tracker, etc:
#   https://launchpad.net/enjuewemela/
#
"""Tests for future guessing."""

import unittest

from enjuewemela.logic_board import future_guess, FakeBoard

class TestFuture(unittest.TestCase):

    def test_empty(self):
        '''Not a chance.'''
        b = ("abcd",
             "efgh",
             "abcd",
             "efgh",
            )

        res = future_guess(FakeBoard(b))
        self.assertEqual(res, None)

    def test_one_chance_vertical_right(self):
        '''one possibility, vertical, right.'''
        b = ("abcd",
             "e.gh",
             "ab.d",
             "e.gh",
            )

        res = future_guess(FakeBoard(b))
        self.assertEqual(res, (2, 1))

    def test_one_chance_vertical_left(self):
        '''one possibility, vertical, left.'''
        b = ("abcd",
             "e.gh",
             ".bad",
             "e.gh",
            )

        res = future_guess(FakeBoard(b))
        self.assertEqual(res, (0, 1))

    def test_one_chance_horizontal_up(self):
        '''One possibility, horizontal, up.'''
        b = ("abcd",
             "ef.h",
             "a.c.",
             "efgh",
            )

        res = future_guess(FakeBoard(b))
        self.assertEqual(res, (2, 2))

    def test_one_chance_horizontal_down(self):
        '''One possibility, horizontal, down.'''
        b = ("abcd",
             "efzh",
             "a.c.",
             "ef.h",
            )

        res = future_guess(FakeBoard(b))
        self.assertEqual(res, (2, 0))

    def test_pattern_2_1(self):
        '''The one to move is in the edge.'''
        b = ("abcd",
             "e..h",
             "abc.",
             "efgh",
            )

        res = future_guess(FakeBoard(b))
        self.assertEqual(res, (3, 1))

    def test_separated(self):
        '''The one to move is one away from other two.'''
        b = ("abcde",
             "e.xhf",
             "a.cdg",
             "efshh",
             "p.xuy",
            )

        res = future_guess(FakeBoard(b))
        self.assertEqual(res, (1, 0))
