# This code is part of the 'enjuewemela' game
# License: GPLv3
# Main author: Facundo Batista
# Code, bug tracker, etc:
#   https://launchpad.net/enjuewemela/
#
"""Tests for the "get around" functionality."""

import unittest

from enjuewemela.logic_board import get_around


class TestCorners(unittest.TestCase):
    """Test the four corners."""

    def test_left_bottom(self):
        """Test left bottom."""
        res = get_around((7, 0))
        self.assertEqual(sorted(res), [        (6, 0), (6, 1),
                                                       (7, 1),
                                                             ])

    def test_left_top(self):
        """Test left top."""
        res = get_around((0, 0))
        self.assertEqual(sorted(res), [
                                                       (0, 1),
                                               (1, 0), (1, 1)])

    def test_right_bottom(self):
        """Test right bottom."""
        res = get_around((7, 7))
        self.assertEqual(sorted(res), [(6, 6), (6, 7),
                                       (7, 6),
                                                             ])

    def test_right_top(self):
        """Test right top."""
        res = get_around((0, 7))
        self.assertEqual(sorted(res), [
                                       (0, 6),
                                       (1, 6), (1, 7),       ])


class TestSides(unittest.TestCase):
    """Test the sides."""

    def test_left(self):
        """Test left."""
        res = get_around((2, 0))
        self.assertEqual(sorted(res), [        (1, 0), (1, 1),
                                                       (2, 1),
                                               (3, 0), (3, 1)])

    def test_right(self):
        """Test right."""
        res = get_around((2, 7))
        self.assertEqual(sorted(res), [(1, 6), (1, 7),
                                       (2, 6),
                                       (3, 6), (3, 7),       ])

    def test_top(self):
        """Test top."""
        res = get_around((0, 3))
        self.assertEqual(sorted(res), [
                                       (0, 2),         (0, 4),
                                       (1, 2), (1, 3), (1, 4)])

    def test_bottom(self):
        """Test bottom."""
        res = get_around((7, 3))
        self.assertEqual(sorted(res), [(6, 2), (6, 3), (6, 4),
                                       (7, 2),         (7, 4),
                                                             ])


class TestMiddle(unittest.TestCase):
    """Test the middle of the board."""

    def test_middle_1(self):
        """Test one position in the middle."""
        res = get_around((2, 3))
        self.assertEqual(sorted(res), [(1, 2), (1, 3), (1, 4),
                                       (2, 2),         (2, 4),
                                       (3, 2), (3, 3), (3, 4)])

    def test_middle_2(self):
        """Test other position in the middle."""
        res = get_around((6, 4))
        self.assertEqual(sorted(res), [(5, 3), (5, 4), (5, 5),
                                       (6, 3),         (6, 5),
                                       (7, 3), (7, 4), (7, 5)])
