# This code is part of the 'enjuewemela' game
# License: GPLv3
# Main author: Facundo Batista
# Code, bug tracker, etc:
#   https://launchpad.net/enjuewemela/
#
"""Some useful functions and classes."""

from cocos import cocosnode
from cocos.text import Label

import pyglet


class FontWriter(object):
    """Wrapper around font."""
    def __init__(self, in_layer, chosen_font):
        self.layer = in_layer
        self.font = chosen_font

    def __call__(self, text, position, size, anchor, color=(0, 0, 0, 255)):
        l = Label(text, position, font_name=self.font, font_size=size,
                  color=color, anchor_x=anchor, anchor_y="center")
        self.layer.add(l)
        return l


class Base(cocosnode.CocosNode):
    """White base for."""
    def __init__(self, alpha, x1, y1, width, height):
        super(Base, self).__init__()
        x2 = x1 + width
        y2 = y1 + height
        self.vertex = (x1, y1, x1, y2, x2, y2, x2, y1)
        self.alpha = alpha

    def draw(self, *args, **kwargs):
        """Draw the white base."""
        pyglet.graphics.glPushMatrix()
        self.transform()
        pyglet.graphics.draw(4, pyglet.graphics.GL_QUADS,
                             ('v2i', self.vertex),
                             ('c4B', (255, 255, 255, self.alpha) * 4))
        pyglet.graphics.glPopMatrix()
